/*
 * This file is part of OpenModelica.
 *
 * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
 * c/o Linköpings universitet, Department of Computer and Information Science,
 * SE-58183 Linköping, Sweden.
 *
 * All rights reserved.
 *
 * THIS PROGRAM IS PROVIDED UNDER THE TERMS OF GPL VERSION 3 LICENSE OR
 * THIS OSMC PUBLIC LICENSE (OSMC-PL) VERSION 1.2.
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE
 * OF THE OSMC PUBLIC LICENSE OR THE GPL VERSION 3, ACCORDING TO RECIPIENTS CHOICE.
 *
 * The OpenModelica software and the Open Source Modelica
 * Consortium (OSMC) Public License (OSMC-PL) are obtained
 * from OSMC, either from the above address,
 * from the URLs: http://www.ida.liu.se/projects/OpenModelica or
 * http://www.openmodelica.org, and in the OpenModelica distribution.
 * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
 *
 * This program is distributed WITHOUT ANY WARRANTY; without
 * even the implied warranty of  MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
 * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
 *
 * See the full OSMC Public License conditions for more details.
 *
 */
/*
 *
 * @author Adeel Asghar <adeel.asghar@liu.se>
 *
 *
 */

#include "TextEditor.h"

TextEditor::TextEditor(ModelWidget *pModelWidget)
  : BaseEditor(pModelWidget)
{
  //! @todo for now set the font of TextEditor to default monospaced font. Later define settings for it and read from there.
  mpPlainTextEdit->setFont(QFont(Helper::monospacedFontInfo.family()));
  mpPlainTextEdit->setTabStopWidth(4 * QFontMetrics(mpPlainTextEdit->font()).width(QLatin1Char(' ')));
}

TextEditor::TextEditor(MainWindow *pMainWindow)
  : BaseEditor(pMainWindow)
{
  //! @todo for now set the font of TextEditor to default monospaced font. Later define settings for it and read from there.
  mpPlainTextEdit->setFont(QFont(Helper::monospacedFontInfo.family()));
  mpPlainTextEdit->setTabStopWidth(4 * QFontMetrics(mpPlainTextEdit->font()).width(QLatin1Char(' ')));
}

/*!
 * \brief ModelicaTextEditor::setPlainText
 * Reimplementation of QPlainTextEdit::setPlainText method.
 * Makes sure we dont update if the passed text is same.
 * \param text the string to set.
 */
void TextEditor::setPlainText(const QString &text)
{
  if (text != mpPlainTextEdit->toPlainText()) {
    mForceSetPlainText = true;
    mpPlainTextEdit->setPlainText(text);
    mForceSetPlainText = false;
  }
}

/*!
 * \brief TextEditor::showContextMenu
 * Create a context menu.
 * \param point
 */
void TextEditor::showContextMenu(QPoint point)
{
  QMenu *pMenu = BaseEditor::createStandardContextMenu();
  pMenu->exec(mapToGlobal(point));
  delete pMenu;
}

/*!
 * \brief TextEditor::contentsHasChanged
 * Slot activated when TextEditor's QTextDocument contentsChanged SIGNAL is raised.
 * Sets the model as modified so that user knows that his current model is not saved.
 * \param position
 * \param charsRemoved
 * \param charsAdded
 */
void TextEditor::contentsHasChanged(int position, int charsRemoved, int charsAdded)
{
  Q_UNUSED(position);
  if (mpModelWidget && mpModelWidget->isVisible()) {
    if (charsRemoved == 0 && charsAdded == 0) {
      return;
    }
    /* if user is changing the text. */
    if (!mForceSetPlainText) {
      mpModelWidget->updateModelText();
    }
  }
}
